@@ -20,7 +20,7 @@ function send_post($url, $post_data) {
   $context = stream_context_create($options);   
   $result = file_get_contents($url, false, $context);   
 
-echo $result;  
+echo "http return:".$result."\n";  
   return $result;   
 }
 $post_data = array(   
