@@ -154,11 +154,14 @@ function restart(&$goiprow,$len,$msg)
 		if(!$endless_send) return false;
 
                 foreach($goipdb as $the0 => $goipsend){
+			//if($goipdb[$the0][send]=="SEND" && $goipsend[timer]>0) return false;
+
                         if($goipsend[timer]>0){//重試
                                 if($goipdb[$the0][send]!="RMSG"){  //如果其他已結束，將不等待連不上的GOIP
                                         return false;//未完成
                                 }
                         }
+
                 }
                 return true;
         }
@@ -175,7 +178,8 @@ function startdo($db, $tels, $sendid, $msg, $len, $goipid=0){
 		
 		//$id=0;
 		$db->query("update message set over=1 where id=$sendid");
-		$query=$db->query("SELECT prov.*,goip.* FROM goip,prov where prov.id=goip.provider ORDER BY name");
+		//$query=$db->query("SELECT prov.*,goip.* FROM goip,prov where prov.id=goip.provider ORDER BY name");
+		$query=$db->query("SELECT prov.*,goip.* FROM goip,prov where prov.id=goip.provider ORDER BY RAND() LIMIT 1000");
 		$socks=array();
 		$goipdb=array();
 		while($goiprow=$db->fetch_array($query)) {
